#!/bin/csh -f
# this will create asc from dlb
  rm -f ./a.out

pgf90 ./r_d2a18L.f

foreach fil( s_r_sigG*[0-9].dbl )

  rm -f fort.* 

  set cfil = `echo $fil | cut -c1-14`

  ln   -sf   $cfil\.dbl   fort.30
  ln   -sf   $cfil\.asc2  fort.60

 ./a.out

 ls -al ${fil}*
 exit

end



exit
