#!/bin/csh -f
# this will create asc from dlb
#  123456789 12345
#  r_sfcG.f0918.gz


  pgf90 -i8 -r8 ./r_d2asfc.f

foreach fil( r_sfcG.f*[0-9] )

  set cfil = `echo $fil | cut -c1-12`

  rm -f fort.*

  ln   -sf   $cfil        fort.21
  ln   -sf   $cfil\.asc   fort.22

./a.out

#ls -al ${fil}*
#exit

end



exit
